@@ -1,5 +1,6 @@
 import os
 from dataclasses import dataclass, field
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, ClassVar, Literal, Optional, TypedDict, Union
 
 import numpy as np
@@ -31,6 +32,7 @@ class Video:
 
     Input: The Video feature accepts as input:
     - A `str`: Absolute path to the video file (i.e. random access is allowed).
+    - A `pathlib.Path`: path to the video file (i.e. random access is allowed).
     - A `dict` with the keys:
 
         - `path`: String with relative path of the video file in a dataset repository.
@@ -125,6 +127,8 @@ class Video:
 
         if isinstance(value, str):
             return {"path": value, "bytes": None}
+        elif isinstance(value, Path):
+            return {"path": str(value.absolute()), "bytes": None}
         elif isinstance(value, (bytes, bytearray)):
             return {"path": None, "bytes": value}
         elif isinstance(value, np.ndarray):
